==> powertools-1.0.tar.bz2: lwp_si_packages/phpsupporttickets/1.7/dAPI.py <==

import deployables_lib as dl
import urlparse
import shutil
import os

dl.load_msgs_module("phpsupporttickets-1.7", symtab = globals())

dir_moves = [('', '')]
file_mods = [{'path' : 'upload/', 'delete' : ''}]

source_patches = [{'file' : 'support_tickets.sql.patch'}]

secure_files = ['config.php', ('upload', 0700, 0777)]
instance_patches = []

pat = "^\s*\$(?P<key>\S+\w)\s*=\s*(?P<value>['\"].*['\"])\s*;(?P<comment>.*)"
sub = "$%(key)s = %(value)s;%(comment)s"

def install(site, site_conf, instance_conf, msgs):

    actions = ['resolve_location', 'check_disk_quota', 'check_mysql_enabled', 
	       'check_pass', 'check_install_loc_owner', '']
    args_dict = {}
    dl.do_install_actions(site, site_conf, instance_conf, msgs,
                          globals(), actions, args_dict)
    if not instance_conf.get('company_name'):
        msgs.append((ERROR, COMPANY_NAME, None))
    if not instance_conf.get('from_name'):
        msgs.append((ERROR, FROM_NAME, None))
    if not instance_conf.get('from_email'):
        msgs.append((ERROR, FROM_EMAIL, None))
    if not instance_conf.get('reply_name'):
        msgs.append((ERROR, REPLY_NAME, None))
    if not instance_conf.get('reply_email'):
        msgs.append((ERROR, REPLY_EMAIL, None))
    if msgs.get_severity() != msgs.ERROR:
        vars = [('sitename', instance_conf['company_name']),
                ('siteurl', instance_conf['url_loc']),
                ('host', dl.get_mysql_host(site)),
                ('user', site_conf['mysql']['dbaseadmin']),
                ('pass', instance_conf['dbpass']),
                ('data', instance_conf['dbname']),
                ('socketfrom', instance_conf['from_email']),
                ('socketfromname', instance_conf['from_name']),
                ('socketreply', instance_conf['reply_email']),
                ('socketreplyname', instance_conf['reply_name']),
                ('sockethost', '127.0.0.1'),
                ('admin_username', instance_conf['instance_admin']),
                ('admin_password', instance_conf['instance_pass1']),
                ('uploadpath', (instance_conf['install_loc'] + '/upload/', dl.MODSTR_JAIL)),
                ('relativepath', instance_conf['url_loc'] + '/upload/')]
        actions = ['db_create', 'db_probe', 'archive_unpack', 'check_index',
		   'edit_conf_file', 'run_sql_file', 'handle_security_mode',
                   'access_url']
        args_dict = {
            'archive_unpack':{'dir_moves': dir_moves,
			      'patches' : source_patches },
            'run_sql_file' : {'file' : 'support_tickets.sql'},
            'handle_security_mode': {'files': secure_files},
            'edit_conf_file':  { 'file': 'config.php', 
				 'lang': 'php', 'pat': pat, 'sub': sub, 
				 'vars': vars }
            }
        dl.do_install_actions(site, site_conf, instance_conf, msgs,
                              globals(), actions, args_dict)

def upgrade(site, site_conf, instance_conf, old_instance_conf, msgs):
      if old_instance_conf['shortname'] == 'phpsupporttickets' and \
         old_instance_conf['version'] == '1.5':
         instance_conf['syncfs'] = 1
         instance_conf['overwritefiles'] = 1
         

	 vars = [('version' ,'v1.7' )]

         actions = ['do_backup',
                   '', 'archive_unpack',
	           'edit_conf_file',		
                   'handle_security_mode']

         args_dict = {
            'archive_unpack': { 'dir_moves' : dir_moves,
                                'patches' : source_patches,
                                'fileinfo' :
                                {'excluded_files' : ['config.php']}},
	     'edit_conf_file':  { 'file': 'config.php',
                                  'lang': 'php', 'pat': pat, 'sub': sub, 'vars': vars },
            'handle_security_mode' : { 'files': ['config.php'] }
	       } 			
         dl.do_upgrade_actions(site, site_conf, instance_conf,
                              old_instance_conf, msgs,
                              globals(), actions, args_dict)

def reconfigure(context, site, site_conf, old_site_conf, instance_conf,
                old_instance_conf, msgs):

    actions = ['handle_url_loc', 'resolve_location', 'require_url_loc', '',
               'archive_unpack', 'handle_username_change', 'handle_db_changes']
    args_dict = {
            'archive_unpack': {'dir_moves': dir_moves,
					'patches' : source_patches,
			                'fileinfo' : {'excluded_files' :
					     ['config.php']}}
            }
    if context != dl.CONTEXT_SITE_EDIT and instance_conf.get('dbpass'):
        actions.insert(0, 'db_probe')
        args_dict['db_probe'] = {'use_old' : 1}
    dl.do_reconfigure_actions(context, site, site_conf, old_site_conf,
                              instance_conf, old_instance_conf, msgs,
                              globals(), actions, args_dict)
    if msgs.get_severity() != msgs.ERROR:
        old_upload = "%s%s" % (dl.site_fs_jail(site, old_site_conf),
                             instance_conf['install_loc'] + '/upload/')
        new_upload = "%s%s" % (dl.site_fs_jail(site, site_conf),
                             instance_conf['install_loc'] + '/upload/')        
        vars = [('siteurl', instance_conf['url_loc'],
                 old_instance_conf['url_loc']),
                ('relativepath', instance_conf['url_loc'] + '/upload/',
                 old_instance_conf['url_loc'] + '/upload/'),
                ('uploadpath', new_upload, old_upload)]
        if dl.mysql_installed(site_conf, old_site_conf):
            vars.extend([('user', site_conf['mysql']['dbaseadmin'],
                          old_site_conf['mysql']['dbaseadmin']),
                         ('data', instance_conf['dbname'],
                          old_instance_conf['dbname'])])
        if context != dl.CONTEXT_SITE_EDIT:
            # We will only change the mysql host if a user specifically
            # invokes reconfigure; we don't want this change to happen
            # during upgrade, when all the sites are edited, but the
            # mysql.sock file hasn't moved yet.
            vars.append(('host', dl.get_mysql_host(site)))
            if instance_conf.get('dbpass'):
                vars.append(('pass', instance_conf['dbpass']))
        actions2 = ['edit_conf_file', 'apply_patch', 'handle_security_mode']
        args_dict = {
            'handle_security_mode': { 'files': secure_files },
            'edit_conf_file' : {'file' : 'config.php', 'lang' : 'php',
                                'pat' : pat, 'sub' : sub, 'vars' : vars},
            'apply_patch' : {'patches' : instance_patches}
            }
        dl.do_reconfigure_actions(context, site, site_conf, old_site_conf,
                                  instance_conf, old_instance_conf, msgs,
                                  globals(), actions2, args_dict)
                
def remove(site, site_conf, instance_conf, msgs):
    dl.db_drop(site, site_conf, instance_conf)
    dl.install_loc_cleanup(site, site_conf, instance_conf, dir_moves,
                           source_patches)
    
def get_instance_configuration(context, site, site_conf, instance_conf,
                               old_instance_conf, locale, msgs):
    instance = dl.dsp_create_instance(instance_conf['shortname'],
                                      instance_conf['version'])
    dl.dsp_fill_instance(context, instance, site, site_conf,
                         instance_conf, old_instance_conf,
                         ['dbname', 'username', 'url_net', 'url_path',
                          'domain_to_path'])
    dl.enable_patches(instance, instance_patches)
    return instance

def regression_test(action, index, test_data):
    return dl.regression_check_index(action, index, test_data,
                                     'Login')

==> powertools-1.0.1.tar.bz2: lwp_si_packages/phpsupporttickets/1.7/dAPI.py <==

import deployables_lib as dl
import urlparse
import shutil
import os

dl.load_msgs_module("phpsupporttickets-1.7", symtab = globals())

dir_moves = [('', '')]
file_mods = [{'path' : 'upload/', 'delete' : ''}]

source_patches = [{'file' : 'support_tickets.sql.patch'}]

secure_files = ['config.php', ('upload', 0700, 0777)]
instance_patches = []

pat = "^\s*\$(?P<key>\S+\w)\s*=\s*(?P<value>['\"].*['\"])\s*;(?P<comment>.*)"
sub = "$%(key)s = %(value)s;%(comment)s"

def install(site, site_conf, instance_conf, msgs):

    actions = ['resolve_location', 'check_disk_quota', 'check_mysql_enabled',
                'check_pass', 'check_install_loc_owner', '']
    args_dict = {}
    dl.do_install_actions(site, site_conf, instance_conf, msgs,
                          globals(), actions, args_dict)
    if not instance_conf.get('company_name'):
        msgs.append((ERROR, COMPANY_NAME, None))
    if not instance_conf.get('from_name'):
        msgs.append((ERROR, FROM_NAME, None))
    if not instance_conf.get('from_email'):
        msgs.append((ERROR, FROM_EMAIL, None))
    if not instance_conf.get('reply_name'):
        msgs.append((ERROR, REPLY_NAME, None))
    if not instance_conf.get('reply_email'):
        msgs.append((ERROR, REPLY_EMAIL, None))
    if msgs.get_severity() != msgs.ERROR:
        vars = [('sitename', instance_conf['company_name']),
                ('siteurl', instance_conf['url_loc']),
                ('host', dl.get_mysql_host(site)),
                ('user', site_conf['mysql']['dbaseadmin']),
                ('pass', instance_conf['dbpass']),
                ('data', instance_conf['dbname']),
                ('socketfrom', instance_conf['from_email']),
                ('socketfromname', instance_conf['from_name']),
                ('socketreply', instance_conf['reply_email']),
                ('socketreplyname', instance_conf['reply_name']),
                ('sockethost', '127.0.0.1'),
                ('admin_username', instance_conf['instance_admin']),
                ('admin_password', instance_conf['instance_pass1']),
                ('uploadpath', (instance_conf['install_loc'] + '/upload/', dl.MODSTR_JAIL)),
                ('relativepath', instance_conf['url_loc'] + '/upload/')]
 
        sql_stmt = ["""
	    insert into tickets_users(tickets_users_name,tickets_users_username,
	    tickets_users_password,tickets_users_email,tickets_users_status) 
            values('%(from_name)s','%(instance_admin)s','%(instance_pass1)s','%(from_email)s',1)
            """ % instance_conf]
        actions = ['db_create', 'db_probe', 'archive_unpack', 'check_index',
                    'edit_conf_file', 'run_sql_file', 'exec_mysql',
                    'handle_security_mode', 'access_url']
        args_dict = {
            'archive_unpack':{'dir_moves': dir_moves,
                    'patches' : source_patches },
            'run_sql_file' : {'file' : 'support_tickets.sql'},
            'exec_mysql' : {'sql' : sql_stmt},
            'handle_security_mode': {'files': secure_files},
            'edit_conf_file':  { 'file': 'config.php',
                                'lang': 'php', 'pat': pat, 'sub': sub,
                                'vars': vars }
            }
        dl.do_install_actions(site, site_conf, instance_conf, msgs,
                              globals(), actions, args_dict)

def upgrade(site, site_conf, instance_conf, old_instance_conf, msgs):
      if old_instance_conf['shortname'] == 'phpsupporttickets' and \
         old_instance_conf['version'] == '1.5':
         instance_conf['syncfs'] = 1
         instance_conf['overwritefiles'] = 1
         

         vars = [('version' ,'v1.7' )]

         actions = ['do_backup',
                   '', 'archive_unpack',
                    'edit_conf_file',
                   'handle_security_mode']

         args_dict = {
            'archive_unpack': { 'dir_moves' : dir_moves,
                                'patches' : source_patches,
                                'fileinfo' :
                                {'excluded_files' : ['config.php']}},
            'edit_conf_file':  { 'file': 'config.php',
                                  'lang': 'php', 'pat': pat, 'sub': sub, 'vars': vars },
            'handle_security_mode' : { 'files': ['config.php'] }
            }
         dl.do_upgrade_actions(site, site_conf, instance_conf,
                              old_instance_conf, msgs,
                              globals(), actions, args_dict)

def reconfigure(context, site, site_conf, old_site_conf, instance_conf,
                old_instance_conf, msgs):

    actions = ['handle_url_loc', 'resolve_location', 'require_url_loc', '',
               'archive_unpack', 'handle_username_change', 'handle_db_changes']
    args_dict = {
            'archive_unpack': {'dir_moves': dir_moves,
					'patches' : source_patches,
                                'fileinfo' : {'excluded_files' :
                                ['config.php']}}
            }
    if context != dl.CONTEXT_SITE_EDIT and instance_conf.get('dbpass'):
        actions.insert(0, 'db_probe')
        args_dict['db_probe'] = {'use_old' : 1}
    dl.do_reconfigure_actions(context, site, site_conf, old_site_conf,
                              instance_conf, old_instance_conf, msgs,
                              globals(), actions, args_dict)
    if msgs.get_severity() != msgs.ERROR:
        old_upload = "%s%s" % (dl.site_fs_jail(site, old_site_conf),
                             instance_conf['install_loc'] + '/upload/')
        new_upload = "%s%s" % (dl.site_fs_jail(site, site_conf),
                             instance_conf['install_loc'] + '/upload/')
        vars = [('siteurl', instance_conf['url_loc'],
                 old_instance_conf['url_loc']),
                ('relativepath', instance_conf['url_loc'] + '/upload/',
                 old_instance_conf['url_loc'] + '/upload/'),
                ('uploadpath', new_upload, old_upload)]
        if dl.mysql_installed(site_conf, old_site_conf):
            vars.extend([('user', site_conf['mysql']['dbaseadmin'],
                          old_site_conf['mysql']['dbaseadmin']),
                         ('data', instance_conf['dbname'],
                          old_instance_conf['dbname'])])
        if context != dl.CONTEXT_SITE_EDIT:
            # We will only change the mysql host if a user specifically
            # invokes reconfigure; we don't want this change to happen
            # during upgrade, when all the sites are edited, but the
            # mysql.sock file hasn't moved yet.
            vars.append(('host', dl.get_mysql_host(site)))
            if instance_conf.get('dbpass'):
                vars.append(('pass', instance_conf['dbpass']))
        actions2 = ['edit_conf_file', 'apply_patch', 'handle_security_mode']
        args_dict = {
            'handle_security_mode': { 'files': secure_files },
            'edit_conf_file' : {'file' : 'config.php', 'lang' : 'php',
                                'pat' : pat, 'sub' : sub, 'vars' : vars},
            'apply_patch' : {'patches' : instance_patches}
            }
        dl.do_reconfigure_actions(context, site, site_conf, old_site_conf,
                                  instance_conf, old_instance_conf, msgs,
                                  globals(), actions2, args_dict)
                
def remove(site, site_conf, instance_conf, msgs):
    dl.db_drop(site, site_conf, instance_conf)
    dl.install_loc_cleanup(site, site_conf, instance_conf, dir_moves,
                           source_patches)
    
def get_instance_configuration(context, site, site_conf, instance_conf,
                               old_instance_conf, locale, msgs):
    instance = dl.dsp_create_instance(instance_conf['shortname'],
                                      instance_conf['version'])
    dl.dsp_fill_instance(context, instance, site, site_conf,
                         instance_conf, old_instance_conf,
                         ['dbname', 'username', 'url_net', 'url_path',
                          'domain_to_path'])
    dl.enable_patches(instance, instance_patches)
    return instance

def regression_test(action, index, test_data):
    return dl.regression_check_index(action, index, test_data,
                                     'Login')
